<?php

namespace Litecms\Feature\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Feature\Models\Features;

class FeaturesPolicy
{

    /**
     * Determine if the given user can view the features.
     *
     * @param UserPolicy $user
     * @param Features $features
     *
     * @return bool
     */
    public function view(UserPolicy $user, Features $features)
    {
        if ($user->canDo('feature.features.view') && $user->isAdmin()) {
            return true;
        }

        return $features->user_id == user_id() && $features->user_type == user_type();
    }

    /**
     * Determine if the given user can create a features.
     *
     * @param UserPolicy $user
     * @param Features $features
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('feature.features.create');
    }

    /**
     * Determine if the given user can update the given features.
     *
     * @param UserPolicy $user
     * @param Features $features
     *
     * @return bool
     */
    public function update(UserPolicy $user, Features $features)
    {
        if ($user->canDo('feature.features.edit') && $user->isAdmin()) {
            return true;
        }

        return $features->user_id == user_id() && $features->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given features.
     *
     * @param UserPolicy $user
     * @param Features $features
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Features $features)
    {
        return $features->user_id == user_id() && $features->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given features.
     *
     * @param UserPolicy $user
     * @param Features $features
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Features $features)
    {
        if ($user->canDo('feature.features.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given features.
     *
     * @param UserPolicy $user
     * @param Features $features
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Features $features)
    {
        if ($user->canDo('feature.features.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
